containertools
==============

.. automodule:: abjad.tools.containertools

.. only:: html

   Concrete classes
   ----------------

   .. autosummary::

      ~abjad.tools.containertools.Cluster.Cluster.Cluster
      ~abjad.tools.containertools.Container.Container.Container
      ~abjad.tools.containertools.FixedDurationContainer.FixedDurationContainer.FixedDurationContainer
      ~abjad.tools.containertools.GraceContainer.GraceContainer.GraceContainer
